--
-- DDL script for validation db
--
DROP TABLE CHEMSHIFTS CASCADE;
DROP TABLE ISOTOPES CASCADE;
DROP TABLE AMBICODES CASCADE;
DROP TABLE AMBIREPLACE CASCADE;
DROP TABLE PSEUDOS CASCADE;
DROP TABLE METHYLS CASCADE;
DROP TABLE METHYLENES CASCADE;
DROP TABLE ATOMNOM CASCADE;
DROP TABLE RESNOM CASCADE;
DROP TABLE ATOMS CASCADE;
DROP TABLE RESIDUES CASCADE;
DROP TABLE RESTYPES CASCADE;
DROP TABLE NOMENCLATURES CASCADE;
COMMIT;
--
-- atom nomenclatures
--
CREATE TABLE NOMENCLATURES (
 ID INTEGER PRIMARY KEY,
 NAME VARCHAR(127) NOT NULL
);
GRANT ALL ON NOMENCLATURES TO PUBLIC;

--
-- residue types
--
CREATE TABLE RESTYPES (
 ID INTEGER PRIMARY KEY,
 NAME VARCHAR(127) NOT NULL
);
GRANT ALL ON RESTYPES TO PUBLIC;

--
-- residues
--
CREATE TABLE RESIDUES (
 ID INTEGER PRIMARY KEY,
 TYPEID INTEGER NOT NULL,
 LABEL VARCHAR(5) NOT NULL,
 CODE VARCHAR(5),
 NAME VARCHAR(127),
 NOMID INTEGER NOT NULL
);
GRANT ALL ON RESIDUES TO PUBLIC;

--
-- residue map
--
CREATE TABLE RESNOM (
 BMRBID INTEGER NOT NULL,
 RESID INTEGER NOT NULL
);
GRANT ALL ON RESNOM TO PUBLIC;

--
-- atoms
--
CREATE TABLE ATOMS (
 ID INTEGER PRIMARY KEY,
 NOMID INTEGER NOT NULL,
 RESID INTEGER NOT NULL,
 NAME VARCHAR(12),
 ATYPE VARCHAR(5),
 PSEUDO CHAR(1),
 AMBICODE INTEGER
);
GRANT ALL ON ATOMS TO PUBLIC;

--
-- chemical shifts
--
CREATE TABLE CHEMSHIFTS (
 ATOMID INTEGER NOT NULL,
 SHIFTAVG FLOAT,
 SHIFTSTD FLOAT,
 SHIFTMIN FLOAT,
 SHIFTMAX FLOAT
);
GRANT ALL ON CHEMSHIFTS TO PUBLIC;

--
-- isotopes
--
CREATE TABLE ISOTOPES (
 ATYPE VARCHAR(5) NOT NULL,
 ISOTOPE INTEGER NOT NULL,
 DEF CHAR(1)
);
GRANT ALL ON ISOTOPES TO PUBLIC;

--
-- invalid ambiguity codes
--
CREATE TABLE AMBICODES (
 ATOMID INTEGER NOT NULL,
 AMBICODE INTEGER NOT NULL
);
GRANT ALL ON AMBICODES TO PUBLIC;

--
-- BMRB pseudo atoms
--
CREATE TABLE PSEUDOS (
 ID INTEGER NOT NULL,
 ATOMID INTEGER NOT NULL
);
GRANT ALL ON PSEUDOS TO PUBLIC;

--
-- atom map
--
CREATE TABLE ATOMNOM (
 BMRBID INTEGER NOT NULL,
 ATOMID INTEGER NOT NULL
);
GRANT ALL ON ATOMNOM TO PUBLIC;

--
-- ambiguity code replacements
--
CREATE TABLE AMBIREPLACE (
 RESID INTEGER NOT NULL,
 ATOMID1 INTEGER NOT NULL,
 ATOMID2 INTEGER NOT NULL,
 ORGCODE INTEGER,
 NEWCODE INTEGER NOT NULL
);
GRANT ALL ON AMBIREPLACE TO PUBLIC;

--
-- NMR-STAR 3.0 to 2.1 atom replacements
--
CREATE TABLE METHYLS (
 RESID INTEGER NOT NULL,
 NAME VARCHAR(5) NOT NULL,
 PSEUDO VARCHAR(5) NOT NULL
);
GRANT ALL ON METHYLS TO PUBLIC;

--
-- methylenes
--
CREATE TABLE METHYLENES (
 RESID INTEGER NOT NULL,
 ATOM1 VARCHAR(5) NOT NULL,
 ATOM2 VARCHAR(5) NOT NULL,
 NEW1 VARCHAR(5) NOT NULL,
 NEW2 VARCHAR(5) NOT NULL
);
GRANT ALL ON METHYLENES TO PUBLIC;
